import { IMapTool } from "geovisto";
import IMapSelection from "../../types/selection/IMapSelection";
/**
 * The class provides API for the selection of map elements.
 * It wraps reference to the source element and list of identifiers of geographic items.
 *
 * @author Jiri Hynek
 */
declare class MapSelection implements IMapSelection {
    private tool;
    private srcIds;
    private allIds;
    /**
     * It creates a map selection.
     *
     * @param tool
     * @param srcIds
     */
    constructor(tool: IMapTool, srcIds: string[]);
    /**
     * It returns the tool of the selected element.
     */
    getTool(): IMapTool;
    /**
     * It returns identifiers of geographical items which were selected.
     */
    getSrcIds(): string[];
    /**
     * It returns identifiers of geographical items which were selected or affected by this selection.
     */
    getIds(): string[];
    /**
     * It compares two map selections.
     *
     * @param selection
     */
    equals(selection: IMapSelection | null): boolean;
    /**
     * It takes geographical items and returns the list of new ids
     * which were added to the list of all ids.
     *
     * @param ids
     */
    addIds(ids: string[]): string[];
}
export default MapSelection;
