import { IMapEvent, IMapForm, IMapFormControl, IMapToolInitProps, MapTool } from "geovisto";
import IMapSelection from "../../types/selection/IMapSelection";
import ISelectionTool from "../../types/tool/ISelectionTool";
import { ISelectionToolAPIGetter } from "../../types/tool/ISelectionToolAPI";
import ISelectionToolConfig from "../../types/tool/ISelectionToolConfig";
import ISelectionToolDefaults from "../../types/tool/ISelectionToolDefaults";
import ISelectionToolProps from "../../types/tool/ISelectionToolProps";
import ISelectionToolState from "../../types/tool/ISelectionToolState";
/**
 * This class provides the selection tool.
 *
 * @author Jiri Hynek
 */
declare class SelectionTool extends MapTool implements ISelectionTool, IMapFormControl {
    /**
     * tool api
     */
    private static api;
    /**
     * TODO: move to the tool state.
     */
    private mapForm;
    /**
     * It creates a new tool with respect to the props.
     *
     * @paramps
     */
    constructor(props?: ISelectionToolProps);
    /**
     * It creates a copy of the uninitialized tool.
     */
    copy(): ISelectionTool;
    /**
     * It returns the props given by the programmer.
     */
    getProps(): ISelectionToolProps;
    /**
     * It returns default values of the selection tool.
     */
    getDefaults(): ISelectionToolDefaults;
    /**
     * It creates new defaults of the tool.
     */
    createDefaults(): ISelectionToolDefaults;
    /**
     * It returns the selection tool state.
     */
    getState(): ISelectionToolState;
    /**
     * It creates the tool state.
     */
    createState(): ISelectionToolState;
    /**
     * It returns the tool API
     */
    getAPIGetter(): ISelectionToolAPIGetter | undefined;
    /**
     * Overrides the super method.
     *
     * @param initProps
     */
    initialize(initProps: IMapToolInitProps<ISelectionToolConfig>): this;
    /**
     * Help method which initializes the API.
     */
    protected initializeAPI(): void;
    /**
     * It creates new filter tool.
     */
    create(): this;
    /**
     *
     * @paramection
     */
    setSelection(selection: IMapSelection | null): void;
    /**
     * It returns a tab fragment.
     */
    getMapForm(): IMapForm;
    /**
     * It creates new tab control.
     */
    protected createMapForm(): IMapForm;
    /**
     * This function is called when a custom event is invoked.
     *
     * @param event
     */
    handleEvent(event: IMapEvent): void;
}
export default SelectionTool;
