import { IMapToolInitProps, MapToolState } from "geovisto";
import IMapSelection from "../../types/selection/IMapSelection";
import ISelectionTool from "../../types/tool/ISelectionTool";
import ISelectionToolConfig from "../../types/tool/ISelectionToolConfig";
import ISelectionToolDefaults from "../../types/tool/ISelectionToolDefaults";
import ISelectionToolProps from "../../types/tool/ISelectionToolProps";
import ISelectionToolState from "../../types/tool/ISelectionToolState";
/**
 * This class provide functions for using selections.
 *
 * @author Jiri Hynek
 */
declare class SelectionToolState extends MapToolState implements ISelectionToolState {
    private selection;
    /**
     * It creates a tool state.
     */
    constructor(tool: ISelectionTool);
    /**
     * It resets state with respect to initial props.
     */
    initialize(defaults: ISelectionToolDefaults, props: ISelectionToolProps, initProps: IMapToolInitProps<ISelectionToolConfig>): void;
    /**
     * The metod takes config and deserializes the values.
     *
     * @param config
     */
    deserialize(config: ISelectionToolConfig): void;
    /**
     * The method serializes the tool state. Optionally, defaults can be set if property is undefined.
     *
     * @param defaults
     */
    serialize(defaults: ISelectionToolDefaults | undefined): ISelectionToolConfig;
    /**
     * It returns the selection property of the tool state.
     */
    getSelection(): IMapSelection | null;
    /**
     * It sets the selection property of the tool state.
     *
     * @param selection
     */
    setSelection(selection: IMapSelection | null): void;
}
export default SelectionToolState;
